ProcessRefreshKind

Struct ProcessRefreshKind 

pub struct ProcessRefreshKind { /* private fields */ }
Used to determine what you want to refresh specifically on the Process type.

⚠️ Just like all other refresh types, ruling out a refresh doesn’t assure you that the information won’t be retrieved if the information is accessible without needing extra computation.

use sysinfo::{ProcessExt, ProcessRefreshKind, System, SystemExt};

let mut system = System::new();

// We don't want to update the CPU information.
system.refresh_processes_specifics(ProcessRefreshKind::everything().without_cpu());

for (_, proc_) in system.processes() {
    // We use a `==` comparison on float only because we know it's set to 0 here.
    assert_eq!(proc_.cpu_usage(), 0.);
}

Implementations

Source

impl ProcessRefreshKind

pub fn new() -> Self

Creates a new ProcessRefreshKind with every refresh set to false.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();

assert_eq!(r.cpu(), false);
assert_eq!(r.disk_usage(), false);
pub fn everything() -> Self

Creates a new ProcessRefreshKind with every refresh set to true.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::everything();

assert_eq!(r.cpu(), true);
assert_eq!(r.disk_usage(), true);
pub fn cpu(&self) -> bool

Returns the value of the “cpu” refresh kind.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.cpu(), false);

let r = r.with_cpu();
assert_eq!(r.cpu(), true);

let r = r.without_cpu();
assert_eq!(r.cpu(), false);
pub fn with_cpu(self) -> Self

Sets the value of the “cpu” refresh kind to true.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.cpu(), false);

let r = r.with_cpu();
assert_eq!(r.cpu(), true);
pub fn without_cpu(self) -> Self

Sets the value of the “cpu” refresh kind to false.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::everything();
assert_eq!(r.cpu(), true);

let r = r.without_cpu();
assert_eq!(r.cpu(), false);
pub fn disk_usage(&self) -> bool

Returns the value of the “disk_usage” refresh kind.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.disk_usage(), false);

let r = r.with_disk_usage();
assert_eq!(r.disk_usage(), true);

let r = r.without_disk_usage();
assert_eq!(r.disk_usage(), false);
pub fn with_disk_usage(self) -> Self

Sets the value of the “disk_usage” refresh kind to true.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.disk_usage(), false);

let r = r.with_disk_usage();
assert_eq!(r.disk_usage(), true);
pub fn without_disk_usage(self) -> Self

Sets the value of the “disk_usage” refresh kind to false.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::everything();
assert_eq!(r.disk_usage(), true);

let r = r.without_disk_usage();
assert_eq!(r.disk_usage(), false);
pub fn user(&self) -> bool

Returns the value of the “user” refresh kind. This refresh is about user_id and group_id. Please note that it has an effect mostly on Windows as other platforms get this information alongside the Process information directly.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.user(), false);

let r = r.with_user();
assert_eq!(r.user(), true);

let r = r.without_user();
assert_eq!(r.user(), false);
pub fn with_user(self) -> Self

Sets the value of the “user” refresh kind to true.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::new();
assert_eq!(r.user(), false);

let r = r.with_user();
assert_eq!(r.user(), true);
pub fn without_user(self) -> Self

Sets the value of the “user” refresh kind to false.

use sysinfo::ProcessRefreshKind;

let r = ProcessRefreshKind::everything();
assert_eq!(r.user(), true);

let r = r.without_user();
assert_eq!(r.user(), false);